@@ -11,8 +11,8 @@ package Spreadsheet::Edit::Preload;
 
 # Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 998.999; }
-our $VERSION = '1000.026'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2024-12-22'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '1000.027'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2025-10-13'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
 use Import::Into;
@@ -48,7 +48,7 @@ sub import {
   }
 
   # Tie variables in the caller's package
-  $sh->tie_column_vars({package => $callpkg}, ':all', ':safe');
+  $sh->tie_column_vars({package => $callpkg}, ':all');
 
   # Make it the 'current sheet' in the caller's package
   Spreadsheet::Edit::sheet( {package => $callpkg}, $sh );
